﻿using System.Collections.Generic;
using NUnit.Framework;
using NUnit.Framework.Extensions;
using NUnit.Framework.SyntaxHelpers;
using UniversalMigrator.Core;

namespace UniversalMigrator.Tests
{
	[TestFixture]
	public class MigrationEngineTests
	{
		public MigrationEngineTests() { }

		[RowTest]
		[Row("2009.q1", "2009.q2")]
		[Row("2009.q3", "2010.q1")]
		public void GetNextReleaseString(string input, string expected)
		{
			var result = MigrationEngine.GetReleaseString(input, MigrationEngine.GetNextRelease);

			Assert.That(result, Is.EqualTo(expected));
		}

		[RowTest]
		[Row("2009.q1", "2009.q1")]
		[Row("2009 Q3", "2009.q3")]
		public void GetReleaseString(string input, string expected)
		{
			var result = MigrationEngine.GetReleaseString(input, null);

			Assert.That(result, Is.EqualTo(expected));
		}

		[Test]
		public void AccumulateChanges()
		{
			var accumulatedChanges = new Dictionary<string, List<SkinChange>>();

			MigrationEngine.AccumulateSkinChanges("2009.q2", ref accumulatedChanges);

			Assert.That(accumulatedChanges.Count, Is.EqualTo(1));
		}
	}
}
